==> ktexteditor-6.18.0-1-x86_64.pkg.tar.zst: usr/include/KF6/KTextEditor/ktexteditor_export.h <==

#ifndef KTEXTEDITOR_EXPORT_H
#define KTEXTEDITOR_EXPORT_H

#ifdef KTEXTEDITOR_STATIC_DEFINE
#  define KTEXTEDITOR_EXPORT
#  define KTEXTEDITOR_NO_EXPORT
#else
#  ifndef KTEXTEDITOR_EXPORT
#    ifdef KF6TextEditor_EXPORTS
        /* We are building this library */
#      define KTEXTEDITOR_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KTEXTEDITOR_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KTEXTEDITOR_NO_EXPORT
#    define KTEXTEDITOR_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KTEXTEDITOR_DECL_DEPRECATED
#  define KTEXTEDITOR_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KTEXTEDITOR_DECL_DEPRECATED_EXPORT
#  define KTEXTEDITOR_DECL_DEPRECATED_EXPORT KTEXTEDITOR_EXPORT KTEXTEDITOR_DECL_DEPRECATED
#endif

#ifndef KTEXTEDITOR_DECL_DEPRECATED_NO_EXPORT
#  define KTEXTEDITOR_DECL_DEPRECATED_NO_EXPORT KTEXTEDITOR_NO_EXPORT KTEXTEDITOR_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KTEXTEDITOR_NO_DEPRECATED
#    define KTEXTEDITOR_NO_DEPRECATED
#  endif
#endif
#include <ktexteditor_version.h>

#define KTEXTEDITOR_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(KTEXTEDITOR_NO_DEPRECATED) && !defined(KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KTEXTEDITOR_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KTEXTEDITOR_NO_DEPRECATED_WARNINGS) && !defined(KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KTEXTEDITOR_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KTEXTEDITOR_NO_DEPRECATED)
#  undef KTEXTEDITOR_DEPRECATED
#  define KTEXTEDITOR_DEPRECATED_EXPORT KTEXTEDITOR_EXPORT
#  define KTEXTEDITOR_DEPRECATED_NO_EXPORT KTEXTEDITOR_NO_EXPORT
#elif defined(KTEXTEDITOR_NO_DEPRECATED_WARNINGS)
#  define KTEXTEDITOR_DEPRECATED
#  define KTEXTEDITOR_DEPRECATED_EXPORT KTEXTEDITOR_EXPORT
#  define KTEXTEDITOR_DEPRECATED_NO_EXPORT KTEXTEDITOR_NO_EXPORT
#else
#  define KTEXTEDITOR_DEPRECATED KTEXTEDITOR_DECL_DEPRECATED
#  define KTEXTEDITOR_DEPRECATED_EXPORT KTEXTEDITOR_DECL_DEPRECATED_EXPORT
#  define KTEXTEDITOR_DEPRECATED_NO_EXPORT KTEXTEDITOR_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KTEXTEDITOR_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KTEXTEDITOR_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KTEXTEDITOR_NO_DEPRECATED
#  define KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT KTEXTEDITOR_VERSION
#endif
#ifdef KTEXTEDITOR_NO_DEPRECATED_WARNINGS
#  define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE
#  ifdef KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE KTEXTEDITOR_VERSION
#  endif
#endif

#ifndef KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KTEXTEDITOR_DEPRECATED
#  define KTEXTEDITOR_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KTEXTEDITOR_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE >= 0x60900
#  define KTEXTEDITOR_DEPRECATED_VERSION_6_9(text) KTEXTEDITOR_DECL_DEPRECATED_TEXT(text)
#else
#  define KTEXTEDITOR_DEPRECATED_VERSION_6_9(text)
#endif
#define KTEXTEDITOR_DEPRECATED_VERSION_6(minor, text)      KTEXTEDITOR_DEPRECATED_VERSION_6_##minor(text)
#define KTEXTEDITOR_DEPRECATED_VERSION(major, minor, text) KTEXTEDITOR_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KTEXTEDITOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KTEXTEDITOR_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KTEXTEDITOR_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KTEXTEDITOR_DEPRECATED_VERSION(major, minor, text)
#  define KTEXTEDITOR_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KTEXTEDITOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KTEXTEDITOR_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KTEXTEDITOR_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* KTEXTEDITOR_EXPORT_H */

==> ktexteditor-6.21.0-1-x86_64.pkg.tar.zst: usr/include/KF6/KTextEditor/ktexteditor_export.h <==

#ifndef KTEXTEDITOR_EXPORT_H
#define KTEXTEDITOR_EXPORT_H

#ifdef KTEXTEDITOR_STATIC_DEFINE
#  define KTEXTEDITOR_EXPORT
#  define KTEXTEDITOR_NO_EXPORT
#else
#  ifndef KTEXTEDITOR_EXPORT
#    ifdef KF6TextEditor_EXPORTS
        /* We are building this library */
#      define KTEXTEDITOR_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KTEXTEDITOR_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KTEXTEDITOR_NO_EXPORT
#    define KTEXTEDITOR_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KTEXTEDITOR_DECL_DEPRECATED
#  define KTEXTEDITOR_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KTEXTEDITOR_DECL_DEPRECATED_EXPORT
#  define KTEXTEDITOR_DECL_DEPRECATED_EXPORT KTEXTEDITOR_EXPORT KTEXTEDITOR_DECL_DEPRECATED
#endif

#ifndef KTEXTEDITOR_DECL_DEPRECATED_NO_EXPORT
#  define KTEXTEDITOR_DECL_DEPRECATED_NO_EXPORT KTEXTEDITOR_NO_EXPORT KTEXTEDITOR_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KTEXTEDITOR_NO_DEPRECATED
#    define KTEXTEDITOR_NO_DEPRECATED
#  endif
#endif
#include <ktexteditor_version.h>

#define KTEXTEDITOR_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(KTEXTEDITOR_NO_DEPRECATED) && !defined(KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KTEXTEDITOR_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KTEXTEDITOR_NO_DEPRECATED_WARNINGS) && !defined(KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KTEXTEDITOR_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KTEXTEDITOR_NO_DEPRECATED)
#  undef KTEXTEDITOR_DEPRECATED
#  define KTEXTEDITOR_DEPRECATED_EXPORT KTEXTEDITOR_EXPORT
#  define KTEXTEDITOR_DEPRECATED_NO_EXPORT KTEXTEDITOR_NO_EXPORT
#elif defined(KTEXTEDITOR_NO_DEPRECATED_WARNINGS)
#  define KTEXTEDITOR_DEPRECATED
#  define KTEXTEDITOR_DEPRECATED_EXPORT KTEXTEDITOR_EXPORT
#  define KTEXTEDITOR_DEPRECATED_NO_EXPORT KTEXTEDITOR_NO_EXPORT
#else
#  define KTEXTEDITOR_DEPRECATED KTEXTEDITOR_DECL_DEPRECATED
#  define KTEXTEDITOR_DEPRECATED_EXPORT KTEXTEDITOR_DECL_DEPRECATED_EXPORT
#  define KTEXTEDITOR_DEPRECATED_NO_EXPORT KTEXTEDITOR_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KTEXTEDITOR_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KTEXTEDITOR_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KTEXTEDITOR_NO_DEPRECATED
#  define KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT KTEXTEDITOR_VERSION
#endif
#ifdef KTEXTEDITOR_NO_DEPRECATED_WARNINGS
#  define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE
#  ifdef KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE KTEXTEDITOR_VERSION
#  endif
#endif

#ifndef KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KTEXTEDITOR_DEPRECATED
#  define KTEXTEDITOR_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KTEXTEDITOR_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KTEXTEDITOR_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE >= 0x60900
#  define KTEXTEDITOR_DEPRECATED_VERSION_6_9(text) KTEXTEDITOR_DECL_DEPRECATED_TEXT(text)
#else
#  define KTEXTEDITOR_DEPRECATED_VERSION_6_9(text)
#endif

#if KTEXTEDITOR_DEPRECATED_WARNINGS_SINCE >= 0x61300
#  define KTEXTEDITOR_DEPRECATED_VERSION_6_19(text) KTEXTEDITOR_DECL_DEPRECATED_TEXT(text)
#else
#  define KTEXTEDITOR_DEPRECATED_VERSION_6_19(text)
#endif
#define KTEXTEDITOR_DEPRECATED_VERSION_6(minor, text)      KTEXTEDITOR_DEPRECATED_VERSION_6_##minor(text)
#define KTEXTEDITOR_DEPRECATED_VERSION(major, minor, text) KTEXTEDITOR_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KTEXTEDITOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KTEXTEDITOR_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KTEXTEDITOR_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KTEXTEDITOR_DEPRECATED_VERSION(major, minor, text)
#  define KTEXTEDITOR_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KTEXTEDITOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KTEXTEDITOR_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KTEXTEDITOR_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* KTEXTEDITOR_EXPORT_H */
